Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authordiosmosis <benaka@piwik.pro>2014-12-12 04:08:17 +0300
committerdiosmosis <benaka@piwik.pro>2014-12-12 04:08:29 +0300
commita34417449b03e1294ba86571eaa51b4577a959dd (patch)
treec2d736d124befc2ea4fd1ad813011c397cbc8651 /tests/PHPUnit/Fixtures/ManySitesImportedLogs.php
parent5c44ca170c36d2ce043ffffe557e0efc402aab21 (diff)
Change IIS log format in log importer script to be more generic and format any log in W3C extended log format. Keeps iis format for backwards compatibility.
Diffstat (limited to 'tests/PHPUnit/Fixtures/ManySitesImportedLogs.php')
-rw-r--r--tests/PHPUnit/Fixtures/ManySitesImportedLogs.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/tests/PHPUnit/Fixtures/ManySitesImportedLogs.php b/tests/PHPUnit/Fixtures/ManySitesImportedLogs.php
index 365527e280..830d22778c 100644
--- a/tests/PHPUnit/Fixtures/ManySitesImportedLogs.php
+++ b/tests/PHPUnit/Fixtures/ManySitesImportedLogs.php
@@ -246,7 +246,7 @@ class ManySitesImportedLogs extends Fixture
$opts = array('--idsite' => $this->idSite,
'--token-auth' => self::getTokenAuth(),
- '--iis-map-field' => array('date-local=date', 'time-local=time', 'cs(Host)=cs-host', 'TimeTakenMS=time-taken'),
+ '--w3c-map-field' => array('date-local=date', 'time-local=time', 'cs(Host)=cs-host', 'TimeTakenMS=time-taken'),
'--enable-http-errors' => false,
'--enable-http-redirects' => false);
@@ -259,12 +259,12 @@ class ManySitesImportedLogs extends Fixture
$opts = array('--idsite' => $this->idSite,
'--token-auth' => self::getTokenAuth(),
- '--iis-map-field' => array(),
+ '--w3c-map-field' => array(),
'--enable-http-redirects' => false);
$output = self::executeLogImporter($logFile, $opts);
- // make sure warning about --iis-time-taken-secs appears in importer output
- self::assertContains("WARNING: netscaler log file being parsed without --iis-time-taken-secs option.", implode("\n", $output));
+ // make sure warning about --w3c-time-taken-secs appears in importer output
+ self::assertContains("WARNING: netscaler log file being parsed without --w3c-time-taken-secs option.", implode("\n", $output));
}
} \ No newline at end of file